#
# spec file for package gwget
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define build_epiphany %{?favor_gtk2}

Name:           gwget
%if 0%{?build_epiphany}
BuildRequires:  epiphany-devel
%endif
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  libgnomeui-devel
BuildRequires:  libnotify-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
Requires:       wget
Version:        1.0.4
Release:        29.5
# FIXME: on version upgrade, check if build_epiphany is still needed (last checked: 1.0.4)
Summary:        GTK+ Front-End to wget
License:        GPL-2.0+
Group:          Productivity/Networking/Web/Utilities
Url:            http://gnome.org/projects/gwget/
Source:         %{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM gwget-epiphany-2.29.patch bgo609544 vuntz@opensuse.org -- Fix build against newer epiphany
Patch0:         gwget-epiphany-2.29.patch
# PATCH-FIX-UPSTREAM gwget-libnotify-0.7.patch bgo#634170 vuntz@opensuse.org -- Fix build with libnotify 0.7
Patch1:         gwget-libnotify-0.7.patch
# PATCH-FIX-UPSTREAM gwget-glib-2.31.patch bgo#665286 dimstar@opensuse.org -- Fix build with glib 2.31
Patch2:         gwget-glib-2.31.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Recommends:     %{name}-lang
%gconf_schemas_prereq

%description
This package contains a graphical user interface for wget.

%lang_package
%prep
%setup -q
translation-update-upstream
%if 0%{?build_epiphany}
%patch0 -p1
%endif
%patch1 -p1
%patch2 -p1

%build
%configure \
        --disable-static \
%if 0%{?build_epiphany}
        --enable-epiphany-extension \
%endif
        --disable-schemas-install
make %{?jobs:-j%jobs}

%install
%makeinstall
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file gwget Network FileTransfer
%find_lang %{name} %{?no_lang_C}
%find_gconf_schemas
# No library is installed, don't install headers:
rm -rf $RPM_BUILD_ROOT/%{_includedir}
%fdupes $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%pre -f %{name}.schemas_pre

%posttrans -f %{name}.schemas_posttrans

%preun -f %{name}.schemas_preun

%if 0%{?suse_version} > 1130

%post
%desktop_database_post
%endif

%if 0%{?suse_version} > 1130

%postun
%desktop_database_postun
%endif

%files -f %{name}.schemas_list
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO THANKS
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/gwget
%{_datadir}/pixmaps/%{name}*.*
%{_datadir}/dbus-1/services/org.gnome.gwget.service
%if 0%{?build_epiphany}
%dir %{_libdir}/epiphany/*/extensions
%{_libdir}/epiphany/*/*/*.*
%endif

%files lang -f %{name}.lang

%changelog
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Dec  1 2011 dimstar@opensuse.org
- Add gwget-glib-2.31.patch: Fix build with glib 2.31.
* Tue May 31 2011 vuntz@opensuse.org
- Disable the build of the epiphany extension with a
  %%build_epiphany define, unless %%favor_gtk2 is set (which means we
  don't build against GNOME 3).
- Add libnotify-devel BuildRequires to build with notification
  support.
- Add gwget-libnotify-0.7.patch to fix build with libnotify 0.7.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Sep 22 2010 vuntz@opensuse.org
- Remove call to autoreconf: it's not needed since
  gwget-epiphany-2.29.patch also updates configure.
* Wed Feb 10 2010 vuntz@opensuse.org
- Add gwget-epiphany-2.29.patch to fix build of extension against
  newer epiphany.
* Fri Nov 27 2009 dimstar@opensuse.org
- Update to version 1.0.4:
  + Fix crash with gtk+-2.18
* Sat Oct 10 2009 dimstar@opensuse.org
- Update to version 1.0.3:
  + Detect Epiphany 2.27/2.28
  + Fix epiphany-extension dbus call
  + Fix menu icon size
  + Port to GtkBuilder
- Drop gwget-schema-install.patch and gwget-epiphany-2.27.patch
- Remove libglade-devel BuildRequires.
* Wed Aug  5 2009 vuntz@novell.com
- Drop gwget-libgnomeui-2.0.patch: it's not needed.
- Add gwget-epiphany-2.27.patch to fix the build of the epiphany
  extension.
- Pass --disable-static and --disable-schemas-install to configure.
- Remove AutoReqProv: it's default now.
- Remove PreReq on filesystem (it's, hrm, always there) and gconf2
  (already covered by gconf_schemas_prereq).
- Remove epiphany, gnutls-devel, indent, libgnomeprintui-devel,
  libidl-devel, libwnck-devel, perl-XML-Parser BuildRequires. They
  are either unneeded or indirect dependencies.
- Update summary and description.
- Add gwget-schema-install.patch to fix --disable-schemas-install.
* Tue Jul  7 2009 mseben@suse.cz
- updated to 1.0.2 version
  Fixes:
  * Fix Epiphany version detection (Götz Waschk)
  * Fix gwget icon and category in desktop file (Götz Waschk)
  * Doesn't break DBus API (David Sedeño)
  Other:
  * Clear dialog code (Jaroslav Imrich)
  * Remove gnome-vfs (David Sedeño)
  * Remove old DBus code (David Sedeño)
- deprecated string_h.patch,icon_suffix.patch,epiphany-2.25.patch
* Mon Mar  9 2009 mseben@suse.cz
- added libgnomeui-devel BuildRequires dependency to fix build errors
* Mon Feb 23 2009 mseben@suse.cz
- add epiphany-2.25.patch to fix epiphany 2.25.91 detection
* Thu Feb 19 2009 mseben@suse.cz
- updated to 1.0.1 version
  * Fix Epiphany Extension.
  * Detects Epiphany vers>2.18 (Christoph Wickert)
- changes in version 1.0.0
  Features:
  * Support m3u filenames: When gwget finishes
  downloading an .m3u file, it asks the user whether it should download
  the files that it contains. If yes, the files will be added as
  additional downloads. (Michael Fotsch)<>
  Fixes:
  * Better log parsing (Rick Benson)
  * Translate --help output (Gabor Kelemen)
  * Destination dir command line option works with open gwget.
  * View menu items as checkboxes instead of radiobuttons
  * All options in recursive dialog marked.
  Other:
  * Port to GIO and get rid of gnome-vfs
  Translations:
  * New: he, lv, nb, th, oc
- deprecated gwget-epi2_24.patch and gwget-iconv.patch
- added string_h.patch to fix unhandled strlen function
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Aug 15 2008 lmichnovic@suse.cz
- detects epiphany up to version 2.24 (epi2_24.patch)
* Fri Mar 28 2008 ro@suse.de
- added libglade2-devel to buildreq
* Mon Mar 17 2008 lmichnovic@suse.cz
- erased non expanded macro @INTLTOOL_ICONV (*iconv.patch)
- added ownership of %%{_libdir}/epiphany/*/extensions dir
* Mon Mar 10 2008 lmichnovic@suse.cz
- fixed include path of libgnomeui (*libgnomeui-2.0.patch)
* Mon Mar  3 2008 lmichnovic@suse.cz
- fixed icon suffix in desktop file (*icon_suffix.patch)
* Wed Feb 27 2008 sbrabec@suse.cz
- Use upstream desktop file.
* Fri Feb 15 2008 lmichnovic@suse.cz
- detects epiphany up to version 2.22 (epi2_22.patch)
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Tue Jul 17 2007 lmichnovic@suse.cz
- builds with current epiphany 2.19 (epi219.patch)
- fixed entry "MultipleArgs" in desktop file
* Tue May 29 2007 lmichnovic@suse.cz
- update to version 0.99
  * Support for Epiphany 2.17 and 2.18 obsoletes epiphany218.patch
  * Check for MD5 Sum in the properties window
  * Put a clear completed download toolbar icon
  * Add -d or --destination-dir option for set the destination
    directory of the url passed in the command line.
  * Use of gtkstatusicon and libnotify for notificacion instead of
    libegg.
  Fixes:
  * Download command line url even if it is the first instance
  * Correct the use when gnome proxy settings is used
  * Reduce the syncs with gconf. Useful with a large download list
  * Provide a dbus service file.
  * Preferences window could become innacesible.
* Sat May 19 2007 coolo@suse.de
- remove X-SuSE-translate from desktop file
* Mon Apr 23 2007 lmichnovic@suse.cz
- fixed wrong executable in desktop file
* Wed Apr 18 2007 lmichnovic@suse.cz
- removed mDNSresponder from BuildReq
* Fri Apr  6 2007 lmichnovic@suse.cz
- removing static libs
* Wed Apr  4 2007 lmichnovic@suse.cz
- configure detects current epiphany 2.18 (epiphany218.patch)
* Thu Jan 11 2007 sbrabec@suse.cz
- Spec file cleanup.
* Sat Dec 30 2006 james@usr-local-bin.org
- Change prefix to /usr; sysconfdir to /etc.
* Mon Dec 11 2006 lmichnovic@suse.cz
- update to version 0.98.2
  * support of epiphany 2.15 and 2.16
  * libnootify 0.4 support
  * use dbus in epiphany extension
  - obsoletes all patches: cvs.patch, epi216.patch
* Wed Oct 18 2006 lmichnovic@suse.cz
- updated to cvs (cvs.patch) - fix uninitialized variable [#211774]
* Sun Sep 17 2006 ro@suse.de
- fix build with current epiphany (make configure accept 2.16)
* Fri Sep 15 2006 lmichnovic@suse.cz
- builds with epiphany 2.16
* Sun Sep  3 2006 ro@suse.de
- update to cvs to build with current epiphany
* Mon Aug  7 2006 lmichnovic@suse.cz
- removed gnomevfs_function_name.patch because of new gnomevfs2
- fixed changed directory of gnome-vfs-mime.h (gnomevfs_path.patch)
* Tue Jun 13 2006 lmichnovic@suse.cz
- Upgrade to version 0.98.1 which obsoletes undefined.patch
  - detects epiphany 2.14
  - and many other fixes in code
- gnomevfs_function_name.patch solves renamed function detecting
  MIME type which is not implemented yet
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 lmichnovic@suse.cz
- excluding static libraries from instalated files
* Tue Jan 10 2006 lmichnovic@suse.cz
- enabled support for epiphany
  epiphany, epiphany-devel added into NFB
* Fri Jan  6 2006 lmichnovic@suse.cz
- update to version 0.97
* Mon Dec  5 2005 lmichnovic@suse.cz
- fixed gcc warning: undefined operation (#136788)
* Fri Sep 16 2005 lmichnovic@suse.cz
- updated to version 0.96
* Fri Jun 24 2005 postadal@suse.cz
- updated to version 0.95
* Sat Jan 22 2005 ro@suse.de
- fix build on lib64
* Fri Jan 21 2005 postadal@suse.cz
- updated to version 0.92.1
- fixed gconf schemas installation [#33114].
* Tue Nov 23 2004 mmj@suse.de
- updated to version 0.90
- massage the desktop file into current days compliance criterias
* Thu Aug  5 2004 postadal@suse.cz
- updated to version 0.13.1
- added desktop file
* Mon Feb 23 2004 adrian@suse.de
- move menu entry to FileTransfer menu
* Fri Feb 20 2004 postadal@suse.cz
- updated to version 0.9 (gwget2)
- removed obsoleted patches: destdir.dif, ac.dif, aliasing-fix.diff,
  intptr-fix.diff
- made link from gwget2 to gwget
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Nov 13 2002 postadal@suse.cz
- fixed compilation warning: "dereferencing type-punned pointer will break
  strict-aliasing rules"
- used intptr_t instead of int where casting to pointer from integer
* Wed Apr  3 2002 postadal@suse.cz
- fixed to compile with autoconf-2.53
* Mon Nov  5 2001 cihlar@suse.cz
- fixed to compile with automake 1.5
* Thu Oct 25 2001 cihlar@suse.cz
- initial version 0.5.2
